function [dbKorisno_ici] = TFD_UsefulInformationExtraction (x, iK, Gamma_ICI, Rc_RICI, h_size);

% The method extracts useful information from TFD using the k-means and ICI/RICI algorithm
% *Requires TFTB toolbox 

% x - (noisy) signal (time-series) 
% iK - total number of classes (e.g. 9)
% Gamma_ICI - Gamma parameter of the ICI method (e.g. 0.5)
% Rc_RICI - Rc parameter of the RICI method (0 for the ICI method)
% h_size - spectrogram window size

%% Parameters 
N=length(x);
map = [1,1,1; 0.5,0.5,0.5; 0.4,0.4,0.4; 0.2,0.2,0.2; 0,0,0];
h=tftb_window(h_size, 'hamming');
dbF=[N N]; 
iTempMaska=[N N]; 

%% TFD
[tfr,t,f]=tfrsp((x),1:N,N,h);
dbImage=tfr;
dbI=mat2gray(dbImage); 
for i=1:1:N
	for j=1:1:N
        dbF(i,j)=floor(dbI(i,j)*1000); 
    end;
end;
    
%% k-means 
   
[cent,maska]=kmeans(dbF,iK);
Klasa = zeros(N,N,iK);
for k=1:1:iK
	for i=1:1:N
        for j=1:1:N
            if maska(i,j)==k
                iTempMaska(i,j)=dbF(i,j);
                Klasa(i,j,k)=iTempMaska(i,j);
            else
                iTempMaska(i,j)=0;
                Klasa(i,j,k)=0;
            end;
        end;
    end;
end;
for i=1:1:iK
    in_ici(i)=nnz(Klasa(:,:,i));
end;
    
%% RICI/ICI
izbaci_ici=ICI_RICI_clustering(in_ici,Gamma_ICI,Rc_RICI);
dbKorisno_ici=Klasa(:,:,izbaci_ici+1);
for i=(izbaci_ici+2):iK
	dbKorisno_ici=dbKorisno_ici+Klasa(:,:,i);
end; 
ici=izbaci_ici;

%% Extracting useful information from TFD     
dbKorisno_ici_Temp=dbKorisno_ici;
for k=1:1:N
	for i=1:1:N
        if(dbKorisno_ici_Temp(k,i)>0)   
            dbKorisno_ici_Temp(k,i)=1;
        end;
    end;
end;
     
%% Plotting 
figure;
subplot(iK+2,1,1);
contour(tfr,30);
title('Noisy TFD');
for k=1:1:iK,
    subplot(iK+2,1,k+1);
    contour(Klasa(:,:,k),30);
    title(sprintf('Class no. %g',k));
end;
subplot(iK+2,1,iK+2);
contour(dbKorisno_ici,30);
title('TFD containing extracted useful information');
